// Create a new FTPClient object
var ftp = new FTPClient();

// Grab references to all the form elements
var serverText = document.getElementById("Server");
var userNameText = document.getElementById("UserName");
var passwordText = document.getElementById("Password");
var serverFileText = document.getElementById("ServerFile");
var firstNameText = document.getElementById("FirstName");
var lastNameText = document.getElementById("LastName");

// This function is called when the 'Submit' button is pressed.
function submit()
{
    // Validate the text-boxes.
    if (serverText.value==="" || userNameText.value==="" 
        || passwordText.value==="" || serverFileText.value===""
        || firstNameText.value==="" || lastNameText.value==="")
    {
        alert("Please enter all fields.");
        return;
    }

    // Set up event-handlers.  
    // These are called when FTPClient completes particular operations.
    ftp.onInitialize = onInitialize;             // called when initialization is complete
    ftp.onConnect = onConnect;                   // called when a connection has been made (or failed)
    ftp.onDisconnect = onDisconnect;             // called when a connection has been closed
    ftp.onUploadText = onUploadText;             // called when a text-file has been upload
    ftp.onError = onError;                       // called when an error occurs
    
    // Set connection parameters.    
    ftp.remoteHost = serverText.value;
    ftp.userName = userNameText.value;
    ftp.password = passwordText.value;
    
    // if we haven't yet initialized then do so, otherwise connect.
    setStatus("Initializing");
    if (!ftp.isInitialized())
    {
        ftp.initialize("IntegralFTP.jar", true, "DEBUG", false);
        // the function, onInitialize, will called when initialization is complete
    }
    else
    {
        ftp.connect();
        // the function, onConnect, will called when initialization is complete
    }
}

// Called when initialization is complete
function onInitialize(status)
{
    setStatus("Connecting");
    ftp.connect();    
    // onConnect(status) is called when this operation completes
}

// Called when a connection has been made (or failed)
function onConnect(status)
{
    if (status.success)
    {
        setStatus("Uploading text");
        var submissionText = "FirstName=" + firstNameText.value + "\nLastName=" + lastNameText.value;
        ftp.uploadText(submissionText, serverFileText.value);
        // onUploadText will be called when the text has been upload
    }
    else
    {
        setStatus("Could not connect.");
    }
}

// Called when text has been upload.
function onUploadText(status)
{
    if (status.success)
    {
        setStatus("Disconnecting");
    }
    else
    {
        setStatus("Could not upload.");
    }
    
    // onDisconnect will be called when a connection has been closed
    ftp.disconnect();
}

// Called when a connection has been closed
function onDisconnect(status)
{
    setStatus("Disconnected");
}

// Called when an error occurs
function onError(status)
{
    alert("Error: " + status.errorMessage);
}

// Updates the text in the status text-box
function setStatus(text)
{
    var statusText = document.getElementById("Status");
    statusText.value = text;
}
